import * as React from "react";
import styled from "styled-components";
import useScrollbarSize from "react-scrollbar-size";
import { AppbarAction, AppbarBackAction, AppbarContent, AppbarHeader } from "react-native-simple-elements/components/Appbar";
import useScreenSize from "react-native-simple-elements/components/Container/utils/useScreenSize";
import AuthorizedUserMenu from "../AuthorizedUserMenu";
import HomeIcon from "@mdi/svg/svg/home.svg";
import AccountIcon from "@mdi/svg/svg/account.svg";
import { View } from "react-native";
const HeaderContainer = styled.div({
  zIndex: 3
});
const LeftContent = styled.div({
  width: 240
});
const defaultProps = {
  isUserIconCircle: true,
  shouldCheckScrollbarSize: false
};

const SimpleHeader = props => {
  const {
    title,
    renderHomeAction,
    showBackIcon,
    backButtonIcon,
    onHomeActionPress,
    onBackActionPress,
    loggedInUser,
    isUserIconCircle,
    shouldCheckScrollbarSize,
    onLoginClick,
    onViewProfileClick,
    onLogoutClick,
    userMenuItems,
    onUserMenuItemPress,
    renderDesktopLeftActions,
    renderDesktopContent,
    renderRightActions
  } = props;
  const {
    isMobileView
  } = useScreenSize();
  const {
    width: scrollbarSize
  } = useScrollbarSize();

  const _handleBackActionPress = () => {
    if (showBackIcon) {
      if (typeof onBackActionPress === "function") {
        onBackActionPress();
      }
    } else {
      if (typeof onHomeActionPress === "function") {
        onHomeActionPress();
      }
    }
  };

  const _handleLoginClick = () => {
    if (typeof onLoginClick === "function") {
      onLoginClick();
    }
  };

  return /*#__PURE__*/React.createElement(HeaderContainer, {
    style: {
      marginRight: shouldCheckScrollbarSize ? scrollbarSize || 0 : 0
    }
  }, /*#__PURE__*/React.createElement(AppbarHeader, null, isMobileView ? /*#__PURE__*/React.createElement(React.Fragment, null, renderHomeAction ? renderHomeAction() : /*#__PURE__*/React.createElement(AppbarBackAction, {
    icon: showBackIcon ? backButtonIcon : HomeIcon,
    onPress: _handleBackActionPress
  }), /*#__PURE__*/React.createElement(AppbarContent, {
    title: title
  })) : null, !isMobileView ? renderDesktopLeftActions ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(LeftContent, null, renderDesktopLeftActions ? renderDesktopLeftActions() : null)) : /*#__PURE__*/React.createElement(AppbarBackAction, {
    icon: HomeIcon
  }) : null, !isMobileView ? renderDesktopContent ? renderDesktopContent() : /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1
    }
  }) : null, renderRightActions ? renderRightActions() : null, loggedInUser !== null && loggedInUser !== void 0 && loggedInUser.userId ? /*#__PURE__*/React.createElement(AuthorizedUserMenu, {
    circle: isUserIconCircle,
    loggedInUser: loggedInUser,
    onViewProfileClick: onViewProfileClick,
    onLogoutClick: onLogoutClick,
    userMenuItems: userMenuItems,
    onUserMenuItemPress: onUserMenuItemPress
  }) : /*#__PURE__*/React.createElement(AppbarAction, {
    icon: AccountIcon,
    onPress: _handleLoginClick
  })));
};

SimpleHeader.defaultProps = defaultProps;
export default SimpleHeader;
//# sourceMappingURL=SimpleHeader.js.map