export var __esModule: boolean;
declare var _default: typeof DropdownPicker;
export default _default;
declare const DropdownPicker_base: any;
/**
 * Menus display a list of choices on temporary elevated surfaces. Their placement varies based on the element that opens them.
 *
 *  <div class="screenshots">
 *   <img class="medium" src="screenshots/menu-1.png" />
 *   <img class="medium" src="screenshots/menu-2.png" />
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { View } from 'react-native';
 * import Provider from 'react-native-simple-elements/components/theme/Provider';
 * import Button from 'react-native-simple-elements/components/Button';
 * import Divider from 'react-native-simple-elements';
 * import DropdownPicker from 'react-native-simple-widgets/widgets/DropdownPicker';
 *
 * const MyComponent = () => {
 *   const [visible, setVisible] = React.useState(false);
 *
 *   const openMenu = () => setVisible(true);
 *
 *   const closeMenu = () => setVisible(false);
 *
 *   return (
 *     <Provider>
 *       <View
 *         style={{
 *           paddingTop: 50,
 *           flexDirection: 'row',
 *           justifyContent: 'center',
 *         }}>
 *         <DropdownPicker
 *           visible={visible}
 *           onDismiss={closeMenu}
 *           anchor={<Button onPress={openMenu}>Show menu</Button>}>
 *           <Menu.Item onPress={() => {}} title="Item 1" />
 *           <Menu.Item onPress={() => {}} title="Item 2" />
 *           <Divider />
 *           <Menu.Item onPress={() => {}} title="Item 3" />
 *         </DropdownPicker>
 *       </View>
 *     </Provider>
 *   );
 * };
 *
 * export default MyComponent;
 * ```
 */
declare class DropdownPicker extends DropdownPicker_base {
    [x: string]: any;
    static getDerivedStateFromProps(nextProps: any, prevState: any): {
        rendered: boolean;
    };
    constructor(...args: any[]);
    componentDidUpdate(prevProps: any): void;
    componentWillUnmount(): void;
    render(): any;
    anchor: any;
    menu: any;
}
